C***********************************************************************
C********************************  STRCCOM *****************************
C***********************************************************************
C**
C**  NAME:  STRCCOM
C**
C**
C**
C**  PURPOSE
C**  =======
C**  INCLUDE FILE                ORIGINAL VERSION   9/14/99  M. BARTH
C**
C**  03/23/00     M. BARTH       ADDED STUFF FOR RAOB, NPN, ACARS 
C**  04/27/01     M. BARTH       - CHANGED SFCDIR & UAPTDIR LENGTHS
C**                              - ADDED RAOB INFO THAT NEEDS RETENTION
C**  07/16/01     M. BARTH       CHANGES FOR WINDOWS (LEN OF *DIR)
C**  07/24/01     M. BARTH       ADDED HYDRO
C**  04/30/02     M. BARTH       CHANGED MAX_QCCHK_P TO MAX_RAOB_QCCHK_P
C**  05/30/02     M. BARTH       CHANGED DIMENSION OF RAOB ARRAYS FROM
C**                              USING UAPT_MXSTRF TO RAOB_MXSTRF, AND
C**                              COMPLETELY REDID RAOB_QCDEP
C**  09/24/03     M. BARTH       ADDED SATW (SATWND)
C**  08/20/04     M. BARTH       ADDED XXX_FNAME FOR USE IN HAVING THE 
C**                              CLOSE ROUTINES DELETE TEMPORARY FILES 
C**                              ON THE MADIS WEB SERVER
C**  09/27/04     L. BENJAMIN    ADDED SATS (SATSND)
C**  09/27/05     L. BENJAMIN    REDUCED COMMENT SIZE.  NO CODE CHANGE.
C**  11/18/05     L. BENJAMIN    ADDED SNOW
C**
C**  THIS COMMON IS USED TO TRACK STATION RECORDS AGAINST THE RECORD 
C**  NUMBERS IN THE NETCDF FILES FROM WHICH THEY WERE READ IN.
C**
C**  VARIABLES
C**  =========
C**  LABEL           TYPE ................DESCRIPTION..................
C**
C**  XXX = SFC IN FOLLOWING NAMES --> SFC SUBSYSTEM
C**  XXX = UAPT                   --> UPPER-AIR-POINT SUBSYSTEM
C**  XXX = HYDRO                  --> HYDRO SUBSYSTEM
C**  XXX = SATW                   --> SATELLITE-WIND SUBSYSTEM
C**  XXX = SATS                   --> SATELLITE-SOUNDING SUBSYSTEM
C**  XXX = SATR                   --> SATELLITE-RADIANCE SUBSYSTEM
C**  XXX = SNOW                   --> SNOW SUBSYSTEM
C======================================================================
C**  XXX_NFILES      I      NUMBER OF NETCDF FILES READ IN
C**  XXX_FNUM        IA     FILE NUMBER (1-XXX_NFILES) FOR EACH STATION
C**  XXX_RNUM        IA     RECORD NUMBER WITHIN THE FILE FOR EACH
C**                         STATION
C**  XXX_LNUM        I      LAST POSITION USED IN XXX_FNUM & XXX_RNUM
C**
C**  XXX_MXSTRF      I      SIZE OF XXX_NFILES ARRAY
C**
C**  XXX_NCID        IA     NETCDF NCID'S FOR THE FILES
C**
C**  XXXDIRLEN       IA     CHAR-LENGTH OF THE DIRECTORY NAMES
C** 
C**  XXX_NRECS       IA     NUMBER OF RECORDS IN EACH FILE
C**
C**  XXX_SOURCE      IA     DATASET CODE NUMBERS FOR EACH FILE
C**
C**  XXX_RECDIM      IA     NETCDF RECORD DIMENSION ID FOR EACH FILE
C**
C**  XXX_FNAME       CA     YYYYMMDD_HHMM NAME OF EACH FILE
C**
C***********************************************************************
C***********************************************************************

C     SFC SUBSYSTEM:

      CHARACTER*255 SFCDIR(MAX_SFCDSET_P)
      CHARACTER*13 SFC_FNAME(SFC_MXSTRF)
      INTEGER SFCDIRLEN(MAX_SFCDSET_P)
      INTEGER SFC_NFILES,SFC_LNUM,SFC_FNUM(MXSFC_P*4)
      INTEGER SFC_RNUM(MXSFC_P*4),SFC_NCID(SFC_MXSTRF)
      INTEGER SFC_NRECS(SFC_MXSTRF)
      INTEGER SFC_SOURCE(SFC_MXSTRF),SFC_RECDIM(SFC_MXSTRF)

      COMMON/SFCSTRC/SFCDIR,SFC_FNAME
      COMMON/SFCSTRN/SFC_NFILES,SFC_LNUM,SFC_FNUM,SFC_RNUM,SFC_NCID,
     1               SFCDIRLEN,SFC_NRECS,SFC_SOURCE,SFC_RECDIM

C     UAPT SUBSYSTEM:

      CHARACTER*255 UAPTDIR(MAX_UAPTDSET_P)
      CHARACTER*13 UAPT_FNAME(UAPT_MXSTRF,MAX_UAPTDSET_P)
      INTEGER UAPTDIRLEN(MAX_UAPTDSET_P)
      INTEGER UAPT_NFILES(MAX_UAPTDSET_P)
      INTEGER UAPT_LNUM(MAX_UAPTDSET_P)
      INTEGER UAPT_FNUM(MXUAPT_P*UAPT_MXSTRF,MAX_UAPTDSET_P)
      INTEGER UAPT_RNUM(MXUAPT_P*UAPT_MXSTRF,MAX_UAPTDSET_P)
      INTEGER UAPT_NCID(UAPT_MXSTRF,MAX_UAPTDSET_P)
      INTEGER UAPT_NRECS(UAPT_MXSTRF,MAX_UAPTDSET_P)
      INTEGER UAPT_RECDIM(UAPT_MXSTRF,MAX_UAPTDSET_P)

      COMMON/UAPTSTRC/UAPTDIR,UAPT_FNAME
      COMMON/UAPTSTRN/UAPT_NFILES,UAPT_LNUM,UAPT_FNUM,UAPT_RNUM,
     1                UAPT_NCID,UAPTDIRLEN,UAPT_NRECS,UAPT_RECDIM

C     HYDRO SUBSYSTEM:

      CHARACTER*255 HYDRODIR(MAX_HYDRODSET_P)
      CHARACTER*13 HYDRO_FNAME(HYDRO_MXSTRF)
      INTEGER HYDRODIRLEN(MAX_HYDRODSET_P)
      INTEGER HYDRO_NFILES,HYDRO_LNUM,HYDRO_FNUM(MXHYDRO_P*4)
      INTEGER HYDRO_RNUM(MXHYDRO_P*4),HYDRO_NCID(HYDRO_MXSTRF)
      INTEGER HYDRO_NRECS(HYDRO_MXSTRF)
      INTEGER HYDRO_SOURCE(HYDRO_MXSTRF),HYDRO_RECDIM(HYDRO_MXSTRF)

      COMMON/HYDROSTRC/HYDRODIR,HYDRO_FNAME
      COMMON/HYDROSTRN/HYDRO_NFILES,HYDRO_LNUM,HYDRO_FNUM,HYDRO_RNUM,
     1                 HYDRO_NCID,HYDRODIRLEN,HYDRO_NRECS,HYDRO_SOURCE,
     2                 HYDRO_RECDIM


C     SATW SUBSYSTEM:

      CHARACTER*255 SATWDIR(MAX_SATWDSET_P)
      CHARACTER*13 SATW_FNAME(SATW_MXSTRF)
      INTEGER SATWDIRLEN(MAX_SATWDSET_P)
      INTEGER SATW_NFILES,SATW_LNUM,SATW_FNUM(MXSATW_P*4)
      INTEGER SATW_RNUM(MXSATW_P*4),SATW_NCID(SATW_MXSTRF)
      INTEGER SATW_NRECS(SATW_MXSTRF)
      INTEGER SATW_SOURCE(SATW_MXSTRF),SATW_RECDIM(SATW_MXSTRF)

      COMMON/SATWSTRC/SATWDIR,SATW_FNAME
      COMMON/SATWSTRN/SATW_NFILES,SATW_LNUM,SATW_FNUM,SATW_RNUM,
     1                SATW_NCID,SATWDIRLEN,SATW_NRECS,SATW_SOURCE,
     2                SATW_RECDIM

C     SATS SUBSYSTEM:

      CHARACTER*255 SATSDIR(MAX_SATSDSET_P)
      INTEGER SATSDIRLEN(MAX_SATSDSET_P)
      INTEGER SATS_NFILES,SATS_LNUM,SATS_FNUM(MXSATS_P*4)
      INTEGER SATS_RNUM(MXSATS_P*4)
      INTEGER SATS_NCID(SATS_MXSTRF)
      INTEGER SATS_NRECS(SATS_MXSTRF)
      INTEGER SATS_SOURCE(SATS_MXSTRF),SATS_RECDIM(SATS_MXSTRF)

      COMMON/SATSSTRC/SATSDIR
      COMMON/SATSSTRN/SATS_NFILES,SATS_LNUM,SATS_FNUM,SATS_RNUM,
     1                SATS_NCID,SATSDIRLEN,SATS_NRECS,SATS_SOURCE,
     2                SATS_RECDIM

C     SATR SUBSYSTEM:

      CHARACTER*255 SATRDIR(MAX_SATRDSET_P)
      INTEGER SATRDIRLEN(MAX_SATRDSET_P)
      INTEGER SATR_NFILES,SATR_LNUM,SATR_FNUM(MXSATR_P*4)
      INTEGER SATR_RNUM(MXSATR_P*4)
      INTEGER SATR_NCID(SATR_MXSTRF)
      INTEGER SATR_NRECS(SATR_MXSTRF)
      INTEGER SATR_SOURCE(SATR_MXSTRF),SATR_RECDIM(SATR_MXSTRF)

      COMMON/SATRSTRC/SATRDIR
      COMMON/SATRSTRN/SATR_NFILES,SATR_LNUM,SATR_FNUM,SATR_RNUM,
     1                SATR_NCID,SATRDIRLEN,SATR_NRECS,SATR_SOURCE,
     2                SATR_RECDIM



C     SNOW SUBSYSTEM:

      CHARACTER*255 SNOWDIR(MAX_SNOWDSET_P)
      CHARACTER*13 SNOW_FNAME(SNOW_MXSTRF)
      INTEGER SNOWDIRLEN(MAX_SNOWDSET_P)
      INTEGER SNOW_NFILES,SNOW_LNUM,SNOW_FNUM(MXSNOW_P*4)
      INTEGER SNOW_RNUM(MXSNOW_P*4),SNOW_NCID(SNOW_MXSTRF)
      INTEGER SNOW_NRECS(SNOW_MXSTRF)
      INTEGER SNOW_SOURCE(SNOW_MXSTRF),SNOW_RECDIM(SNOW_MXSTRF)

      COMMON/SNOWSTRC/SNOWDIR,SNOW_FNAME
      COMMON/SNOWSTRN/SNOW_NFILES,SNOW_LNUM,SNOW_FNUM,SNOW_RNUM,
     1                 SNOW_NCID,SNOWDIRLEN,SNOW_NRECS,SNOW_SOURCE,
     2                 SNOW_RECDIM




C     RAOB DATA:

      INTEGER RAOB_LT(MXRAOBLEV_P,MXRAOB_P,RAOB_MXSTRF)
      REAL RAOB_OB(MXRAOBLEV_P,MXRAOB_P,MXRAOBVAR_P,RAOB_MXSTRF)
      REAL RAOB_QCA(MXRAOBLEV_P,MXRAOB_P,MXRAOBVAR_P,RAOB_MXSTRF)
      REAL RAOB_QCR(MXRAOBLEV_P,MXRAOB_P,MXRAOBVAR_P,RAOB_MXSTRF)
      REAL RAOB_QCDEP(MXRAOBLEV_P,MXRAOB_P,MXRAOBVAR_P,RAOB_MXSTRF)
      CHARACTER*1 RAOB_QCDD(MXRAOBLEV_P,MXRAOB_P,MXRAOBVAR_P,
     1                      RAOB_MXSTRF)
      INTEGER RAOB_NLEVELS(MXRAOB_P,RAOB_MXSTRF)
      REAL RAOB_LT_COUNT(MXRAOB_P,6,RAOB_MXSTRF)
      INTEGER RAOB_FNUM

      COMMON/RAOBSTRC/RAOB_QCDD
      COMMON/RAOBSTRN/RAOB_LT,RAOB_OB,RAOB_QCA,RAOB_QCR,RAOB_QCDEP,
     1                RAOB_NLEVELS,RAOB_LT_COUNT,RAOB_FNUM


C     WISDOM SUBSYSTEM:

      CHARACTER*255 WISDOMDIR(MAX_WISDOMDSET_P)
      CHARACTER*13 WISDOM_FNAME(WISDOM_MXSTRF)
      INTEGER WISDOMDIRLEN(MAX_WISDOMDSET_P)
      INTEGER WISDOM_NFILES,WISDOM_LNUM,WISDOM_FNUM(MXWISDOM_P*4)
      INTEGER WISDOM_RNUM(MXWISDOM_P*4),WISDOM_NCID(WISDOM_MXSTRF)
      INTEGER WISDOM_NRECS(WISDOM_MXSTRF)
      INTEGER WISDOM_SOURCE(WISDOM_MXSTRF),WISDOM_RECDIM(WISDOM_MXSTRF)

      COMMON/WISDOMSTRC/WISDOMDIR,WISDOM_FNAME
      COMMON/WISDOMSTRN/WISDOM_NFILES,WISDOM_LNUM,WISDOM_FNUM,
     1     WISDOM_RNUM,WISDOM_NCID,WISDOMDIRLEN,WISDOM_NRECS,
     2     WISDOM_SOURCE,WISDOM_RECDIM

