C$$$   SUBPROGRAM DOCUMENTATION BLOCK
C                .      .    .                                       .
C SUBPROGRAM:    M_PRSALT    GET ALT SETTING FROM SFC PRESSURE 
C
C   PRGMMR:  M. BARTH       ORG: FSL            DATE: 00-06-15
C
C ABSTRACT:  DETERMINE ALTIMETER SETTING FROM SURFACE PRESSURE 
C            AND ELEVATION.
C
C PROGRAM HISTORY LOG:
C    00-06-15      M. BARTH        ORIGINAL VERSION
C    01-07-20      M. BARTH        TURNED INTO A FUNCTION FOR MADIS
C    03-02-28      M. BARTH        FIXED ERRORS THAT PRODUCED SMALL 
C                                  ERRORS THAT GREW LARGER (UP TO 
C                                  SAY 2 MB) AS THE PRESSURE VARIED
C                                  FARTHER FROM THE STD ATMOS MODEL.
C    03-07-08      M. BARTH        REMOVED DECLARATIONS OF VARIABLES
C                                  THAT AREN'T USED.
C
C USAGE:           M_PRSALT = M_PRSALT(PRES,ELEV)
C
C   INPUT ARGUMENT LIST:
C     PRES     - REAL     SURFACE PRESSURE IN MB
C     ELEV     - REAL     STATION ELEVATION IN METERS
C   OUTPUT ARGUMENT LIST:
C     M_PRSALT - REAL     ALTIMETER SETTING IN MB
C
C REMARKS: NONE
C
C ATTRIBUTES:
C   LANGUAGE: FORTRAN-77 + EXTENSIONS
C   MACHINE: UNIX
C
C$$$


      REAL FUNCTION M_PRSALT(PRES,ELEV)

C     CONSTANTS

      INCLUDE 'IMPLICIT'

      REAL EXP,EXPINV,CONST,LAPSE,TSTD,PSTD
      PARAMETER (EXP = 0.190284)
      PARAMETER (EXPINV = 1./EXP)
      PARAMETER (LAPSE = 0.0065)
      PARAMETER (TSTD = 288.15)
      PARAMETER (PSTD = 1013.25)

C     ARGUMENTS
      REAL ELEV
      REAL PRES

      CONST = PSTD**EXP * LAPSE/TSTD

      M_PRSALT = ((PRES - 0.3)**EXP + CONST * ELEV)**EXPINV

      RETURN
      END
C**---------------------------------------------------------------------
C**REQUIRED STANDARD FSL DISCLAIMER (NOVEMBER 2000)
C**---------------------------------------------------------------------
C**  OPEN SOURCE LICENSE/DISCLAIMER,  FORECAST SYSTEMS LABORATORY
C**  NOAA/OAR/FSL, 325 BROADWAY BOULDER, CO 80305
C**
C**  THIS SOFTWARE IS DISTRIBUTED UNDER THE OPEN SOURCE DEFINITION, 
C**  WHICH MAY BE FOUND AT http://www.opensource.org/osd.html.
C**
C**  IN PARTICULAR, REDISTRIBUTION AND USE IN SOURCE AND BINARY FORMS,
C**  WITH OR WITHOUT MODIFICATION, ARE PERMITTED PROVIDED THAT THE 
C**  FOLLOWING CONDITIONS ARE MET:
C**
C**  - REDISTRIBUTIONS OF SOURCE CODE MUST RETAIN THIS NOTICE, THIS LIST
C**    OF CONDITIONS AND THE FOLLOWING DISCLAIMER.
C**
C**  - REDISTRIBUTIONS IN BINARY FORM MUST PROVIDE ACCESS TO THIS 
C**    NOTICE, THIS LIST OF CONDITIONS AND THE FOLLOWING DISCLAIMER, AND
C**    THE UNDERLYING SOURCE CODE.
C**
C**  - ALL MODIFICATIONS TO THIS SOFTWARE MUST BE CLEARLY DOCUMENTED, 
C**    AND ARE SOLELY THE RESPONSIBILITY OF THE AGENT MAKING THE 
C**    MODIFICATIONS.
C**
C**  - IF SIGNIFICANT MODIFICATIONS OR ENHANCEMENTS ARE MADE TO THIS
C**    SOFTWARE, THE FSL SOFTWARE POLICY MANAGER 
C**    (softwaremgr.fsl@noaa.gov) BE NOTIFIED.
C**
C**  THIS SOFTWARE AND ITS DOCUMENTATION ARE IN THE PUBLIC DOMAIN AND 
C**  ARE FURNISHED "AS IS."  THE AUTHORS, THE UNITED STATES GOVERNMENT,
C**  ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO 
C**  WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE
C**  AND DOCUMENTATION FOR ANY PURPOSE.  THEY ASSUME NO RESPONSIBILITY 
C**  (1) FOR THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO 
C**  PROVIDE TECHNICAL SUPPORT TO USERS.
C**---------------------------------------------------------------------
