C$$$  SUBPROGRAM DOCUMENTATION BLOCK
C                .      .    .                                       .
C SUBPROGRAM:    M_ROTFAC    ADJUSTS THE WINDS TO GRID COORDINATES
C   PRGMMR: TRACY, SMITH     ORG: FSL/PROFS  DATE: 90-06-15
C
C ABSTRACT: ADJUSTS THE WINDS TO GRID COORDINATES
C
C PROGRAM HISTORY LOG:
C   90-06-15  T.L. SMITH  ORIGINAL VERSION
C   99-08-17  M. BARTH    - REDEFINED LON_XX (REMOVED -90)
C                         - ADDED ROTCON ARG
C                         - REORDERED ARGS INPUT THEN OUTPUT
C
C USAGE:    CALL M_ROTFAC(LONG,LON_XX,ROTCON,SINDL,COSDL)
C   INPUT ARGUMENT LIST:
C     LONG    - REAL   LONGITUDE OF THE WIND OBSERVATION (DEG)
C     LON_XX  - REAL   MERIDIAN ALIGNED W/X-AXIS (DEG.)
C     ROTCON  - REAL   WIND ROTATION CONSTANT
C
C   OUTPUT ARGUMENT LIST:
C     SINDL   - REAL   ADJUSTED SIN OF DEGREES LONGITUDE WITH
C               RESPECT TO CENTER OF GRID DOMAIN.
C     COSDL   - REAL   ADJUSTED COS OF DEGREES LONGITUDE WITH
C               RESPECT TO CENTER OF GRID DOMAIN.
C
C REMARKS:
C
C ATTRIBUTES:
C   LANGUAGE: FORTRAN-77
C   MACHINE:  UNIX
C$$$

      SUBROUTINE M_ROTFAC(LONG,LON_XX,ROTCON,SINDL,COSDL)
C*** THIS ROUTINE ADJUSTS THE WINDS TO GRID COORDINATES

      INCLUDE 'IMPLICIT'

      REAL LONG,SINDL,COSDL,X,LON_XX,ROTCON

      X=ROTCON*(LON_XX-LONG)
      SINDL=SIN(X*1.74 53292 51994 32957 69237 E-02)
      COSDL=COS(X*1.74 53292 51994 32957 69237 E-02)
      RETURN
       END
C**---------------------------------------------------------------------
C**REQUIRED STANDARD FSL DISCLAIMER (NOVEMBER 2000)
C**---------------------------------------------------------------------
C**  OPEN SOURCE LICENSE/DISCLAIMER,  FORECAST SYSTEMS LABORATORY
C**  NOAA/OAR/FSL, 325 BROADWAY BOULDER, CO 80305
C**
C**  THIS SOFTWARE IS DISTRIBUTED UNDER THE OPEN SOURCE DEFINITION, 
C**  WHICH MAY BE FOUND AT http://www.opensource.org/osd.html.
C**
C**  IN PARTICULAR, REDISTRIBUTION AND USE IN SOURCE AND BINARY FORMS,
C**  WITH OR WITHOUT MODIFICATION, ARE PERMITTED PROVIDED THAT THE 
C**  FOLLOWING CONDITIONS ARE MET:
C**
C**  - REDISTRIBUTIONS OF SOURCE CODE MUST RETAIN THIS NOTICE, THIS LIST
C**    OF CONDITIONS AND THE FOLLOWING DISCLAIMER.
C**
C**  - REDISTRIBUTIONS IN BINARY FORM MUST PROVIDE ACCESS TO THIS 
C**    NOTICE, THIS LIST OF CONDITIONS AND THE FOLLOWING DISCLAIMER, AND
C**    THE UNDERLYING SOURCE CODE.
C**
C**  - ALL MODIFICATIONS TO THIS SOFTWARE MUST BE CLEARLY DOCUMENTED, 
C**    AND ARE SOLELY THE RESPONSIBILITY OF THE AGENT MAKING THE 
C**    MODIFICATIONS.
C**
C**  - IF SIGNIFICANT MODIFICATIONS OR ENHANCEMENTS ARE MADE TO THIS
C**    SOFTWARE, THE FSL SOFTWARE POLICY MANAGER 
C**    (softwaremgr.fsl@noaa.gov) BE NOTIFIED.
C**
C**  THIS SOFTWARE AND ITS DOCUMENTATION ARE IN THE PUBLIC DOMAIN AND 
C**  ARE FURNISHED "AS IS."  THE AUTHORS, THE UNITED STATES GOVERNMENT,
C**  ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO 
C**  WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE
C**  AND DOCUMENTATION FOR ANY PURPOSE.  THEY ASSUME NO RESPONSIBILITY 
C**  (1) FOR THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO 
C**  PROVIDE TECHNICAL SUPPORT TO USERS.
C**---------------------------------------------------------------------
