C$$$  SUBPROGRAM DOCUMENTATION BLOCK
C                .      .    .                                       .
C SUBPROGRAM:    MHYDROINIT  INITIALIZE MADIS HYDRO DATA
C   PRGMMR: M. BARTH         ORG: FSL        DATE: 01-07-24
C
C ABSTRACT: READ FILES TO GET PARAMETERS SPECIFIYING WHAT WE NEED TO
C   KNOW TO READ NETCDF VARIABLES AND PROCESS THEM FOR HYDRO DATASETS,
C   AND FOR ANY OTHER INFO NEEDED ONE TIME FOR HYDRO PROCESSING.
C
C PROGRAM HISTORY LOG:
C   01-07-24  M. BARTH    ORIGINAL VERSION
C   03-05-27  M. BARTH    - REMOVED SUBSRCIN ARGUMENT AND RELATED WORK
C                         - INITIALIZE DATA STRUCTURES THAT TRACK NEW
C                           PROVIDERS
C
C USAGE:    CALL MHYDROINIT (HYDROTBL,STATUS)
C
C   INPUT ARGUMENT LIST:
C
C     HYDROTBL - C       FILENAME OF THE MADIS HYDRO TABLE
C     STADIC   - C       FILENAME OF THE ASOS STATION DICTIONARY
C
C   OUTPUT ARGUMENT LIST:
C     STATUS   - I       SUCCESS_P OR FAILURE CODE
C
C   INPUT FILES:
C     HYDROTBL - FILE SPECIFYING THE VARIABLES IN THE MADIS NETCDF FILES
C
C SUBPROGRAMS CALLED:
C     UNIQUE:    MHYDROTBL
C
C REMARKS:
C   - LIMITED ERROR CHECKING IS DONE ON THE TABLE, AS IT'S MEANT TO
C     BE STATIC AND CREATED AT CODE DEVELOPMENT TIME.
C   - THE MADISCOM PROVIDER ARRAYS (NPVD, PVDNAME, ETC.) HAVE SFC
C     PROVIDERS IN ROW 1, HYDRO PROVIDERS IN ROW 2, MAP PROVIDERS 
C     IN ROW 3.
C
C ATTRIBUTES:
C   LANGUAGE: FORTRAN-77 + EXTENSIONS
C   MACHINE:  UNIX
C$$$

      SUBROUTINE MHYDROINIT(HYDROTBL,STATUS)

C     INCLUDES AND COMMONS
C     ------------------------------------------------------------------
      INCLUDE 'IMPLICIT'
      INCLUDE 'MADISCON'
      INCLUDE 'MADISCOM'

C     ------------------------------------------------------------------
C     ARGUMENTS
C     ------------------------------------------------------------------
      CHARACTER*(*) HYDROTBL
      INTEGER       STATUS

C     ------------------------------------------------------------------
C     LOCAL
C     ------------------------------------------------------------------
      INTEGER       I

C     ---------------------------------------------------------------
C     INITIALIZE MADISCOM VARIABLES.
C     ---------------------------------------------------------------
      DO 1200 I = 1, MAX_HYDRODSET_P
         HYDRODSET_ENBL(I) = .TRUE.
 1200 CONTINUE

      DO 1201 I = 1, MAX_SUBSRC_P
         PROVDR_ENBL(I,2) = .TRUE.
 1201 CONTINUE

      NNEWPVD(2) = 0
      ALL_ENBL(2) = .TRUE.

      HYDRODSET_NAME(1) = 'HYDRO    '

      LAST_HYDRO_ATIME = '         '

      DMTYPE = -1
      QCTYPE = 0

      MINBCK = 0
      MINFWD = 0
      RECWIN = 0

      HYDRO_INIT = INIT_P

C     ------------------------------------------------------------------
C     READ IN THE MADIS HYDRO TABLE (DEFINES VARIABLES AND DATASETS).
C     MHYDROTBL WILL REPORT ANY ERRORS AND SET STATUS.
C     ------------------------------------------------------------------
      CALL MHYDROTBL(HYDROTBL,STATUS)

      RETURN
      END
C**---------------------------------------------------------------------
C**REQUIRED STANDARD FSL DISCLAIMER (NOVEMBER 2000)
C**---------------------------------------------------------------------
C**  OPEN SOURCE LICENSE/DISCLAIMER,  FORECAST SYSTEMS LABORATORY
C**  NOAA/OAR/FSL, 325 BROADWAY BOULDER, CO 80305
C**
C**  THIS SOFTWARE IS DISTRIBUTED UNDER THE OPEN SOURCE DEFINITION, 
C**  WHICH MAY BE FOUND AT http://www.opensource.org/osd.html.
C**
C**  IN PARTICULAR, REDISTRIBUTION AND USE IN SOURCE AND BINARY FORMS,
C**  WITH OR WITHOUT MODIFICATION, ARE PERMITTED PROVIDED THAT THE 
C**  FOLLOWING CONDITIONS ARE MET:
C**
C**  - REDISTRIBUTIONS OF SOURCE CODE MUST RETAIN THIS NOTICE, THIS LIST
C**    OF CONDITIONS AND THE FOLLOWING DISCLAIMER.
C**
C**  - REDISTRIBUTIONS IN BINARY FORM MUST PROVIDE ACCESS TO THIS 
C**    NOTICE, THIS LIST OF CONDITIONS AND THE FOLLOWING DISCLAIMER, AND
C**    THE UNDERLYING SOURCE CODE.
C**
C**  - ALL MODIFICATIONS TO THIS SOFTWARE MUST BE CLEARLY DOCUMENTED, 
C**    AND ARE SOLELY THE RESPONSIBILITY OF THE AGENT MAKING THE 
C**    MODIFICATIONS.
C**
C**  - IF SIGNIFICANT MODIFICATIONS OR ENHANCEMENTS ARE MADE TO THIS
C**    SOFTWARE, THE FSL SOFTWARE POLICY MANAGER 
C**    (softwaremgr.fsl@noaa.gov) BE NOTIFIED.
C**
C**  THIS SOFTWARE AND ITS DOCUMENTATION ARE IN THE PUBLIC DOMAIN AND 
C**  ARE FURNISHED "AS IS."  THE AUTHORS, THE UNITED STATES GOVERNMENT,
C**  ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO 
C**  WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE
C**  AND DOCUMENTATION FOR ANY PURPOSE.  THEY ASSUME NO RESPONSIBILITY 
C**  (1) FOR THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO 
C**  PROVIDE TECHNICAL SUPPORT TO USERS.
C**---------------------------------------------------------------------
