C$$$  SUBPROGRAM DOCUMENTATION BLOCK
C                .      .    .                                       .
C SUBPROGRAM:    MMAPBEAMC   GET MAP BEAM-DIMENSIONED CHAR. VARIABLE
C   PRGMMR: M. BARTH         ORG: FSL        DATE: 02-05-01
C
C ABSTRACT: GET MAP CHARACTER VARIABLE THAT'S DIMENSIONED BY ANTENNA 
C   BEAM FROM ONE FILE FOR ONE TIME.
C
C PROGRAM HISTORY LOG:
C   02-05-01  M. BARTH    ORIGINAL VERSION
C
C USAGE:    CALL MMAPBEAMC (VCN,DSN,FNUM,CDATA,LEN1REC,STATUS)
C
C   INPUT ARGUMENT LIST:
C     VCN      - I       VARIABLE CODE NUMBER
C     DSN      - I       DATASET CODE NUMBER
C     FNUM     - I       FILE NUMBER (INDEX IN COMMON) OF NETCDF FILE
C
C   OUTPUT ARGUMENT LIST:
C     CDATA    - CA      ARRAY OF RETURNED CHARACTER DATA
C     LEN1REC  - I       NUMBER OF CHARACTERS IN EACH RECORD RETURNED
C     STATUS   - I       SUCCESS_P OR ERROR CODE
C
C   INPUT FILES:
C     NETCDF FILE OPENED USING DATA STRUCTURES FOR FNUM IN STRCCOM
C
C SUBPROGRAMS CALLED:
C     UNIQUE:    MGTCHR
C
C REMARKS:
C   - "BEAM-DIMENSIONED" VARIABLES CAN ONLY BE REQUESTED FOR ONE
C     ANTENNA BEAM AT A TIME.  THIS IS DONE WITH THE VCN'S AVAILABLE
C     FOR THESE MAP VARIABLES.
C   - THERE ARE CURRENTLY ONLY 1 SET OF BEAM-DIMENSIONED CHARACTER
C     VARIABLES -- BEAM NAMES, WHICH HAVE 8 CHARACTERS.  THIS IS
C     HARD-WIRED...
C   - SEE madistmp.f FOR AN EXPLANATION OF HOW TEMPORARY STORAGE
C     IS HANDLED (ALL ARRAYS NAMED *TMP*).
C
C ATTRIBUTES:
C   LANGUAGE: FORTRAN-77 + EXTENSIONS
C   MACHINE:  UNIX
C$$$

      SUBROUTINE MMAPBEAMC (VCN,DSN,FNUM,CDATA,LEN1REC,STATUS)

C     ------------------------------------------------------------------
C     INCLUDES AND COMMONS
C     ------------------------------------------------------------------
      INCLUDE 'IMPLICIT'
      INCLUDE 'MADISCON'
      INCLUDE 'MADISCOM'
      INCLUDE 'STRCCOM'
      INCLUDE 'MADISTMP'

C     ------------------------------------------------------------------
C     ARGUMENTS
C     ------------------------------------------------------------------
      INTEGER VCN,DSN,FNUM,LEN1REC,STATUS
      CHARACTER*8 CDATA(*)

C     ------------------------------------------------------------------
C     LOCAL
C     ------------------------------------------------------------------
      INTEGER I,K,CD
      CHARACTER*8 CTMP(5,MXMAP_P)

C     ------------------------------------------------------------------
C     TEMPORARY STORAGE DEFINITIONS
C     ------------------------------------------------------------------
      EQUIVALENCE(CTMP,TMP_L2_C1)

C     ------------------------------------------------------------------
C     READ IN THE VARIABLE INTO LOCAL ARRAY.
C     ------------------------------------------------------------------
      CD = DSN - MAX_SFCDSET_P
      LEN1REC = 8

      CALL MGTCHR(VNAME(VCN,DSN)(1:VLEN(VCN,DSN)),UAPT_NCID(FNUM,CD),
     1            UAPT_RECDIM(FNUM,CD),1,UAPT_NRECS(FNUM,CD),CTMP,I,
     2            STATUS)
      IF(STATUS.NE.SUCCESS_P)RETURN

C     ------------------------------------------------------------------
C     DETERMINE WHICH BEAM NUMBER THE CALLER WANTS, THEN RETURN THE
C     DATA IN HIS ARRAY AND RETURN.
C     ------------------------------------------------------------------
      IF(VCN.EQ.MAPBEAM_1_VN_P)THEN
         K = 1
      ELSE IF(VCN.EQ.MAPBEAM_2_VN_P)THEN
         K = 2
      ELSE IF(VCN.EQ.MAPBEAM_3_VN_P)THEN
         K = 3
      ELSE IF(VCN.EQ.MAPBEAM_4_VN_P)THEN
         K = 4
      ELSE 
         K = 5
      ENDIF

      DO 11 I = 1, UAPT_NRECS(FNUM,CD)

         CDATA(I) = CTMP(K,I)

 11   CONTINUE

      RETURN
      END
C**---------------------------------------------------------------------
C**REQUIRED STANDARD FSL DISCLAIMER (NOVEMBER 2000)
C**---------------------------------------------------------------------
C**  OPEN SOURCE LICENSE/DISCLAIMER,  FORECAST SYSTEMS LABORATORY
C**  NOAA/OAR/FSL, 325 BROADWAY BOULDER, CO 80305
C**
C**  THIS SOFTWARE IS DISTRIBUTED UNDER THE OPEN SOURCE DEFINITION, 
C**  WHICH MAY BE FOUND AT http://www.opensource.org/osd.html.
C**
C**  IN PARTICULAR, REDISTRIBUTION AND USE IN SOURCE AND BINARY FORMS,
C**  WITH OR WITHOUT MODIFICATION, ARE PERMITTED PROVIDED THAT THE 
C**  FOLLOWING CONDITIONS ARE MET:
C**
C**  - REDISTRIBUTIONS OF SOURCE CODE MUST RETAIN THIS NOTICE, THIS LIST
C**    OF CONDITIONS AND THE FOLLOWING DISCLAIMER.
C**
C**  - REDISTRIBUTIONS IN BINARY FORM MUST PROVIDE ACCESS TO THIS 
C**    NOTICE, THIS LIST OF CONDITIONS AND THE FOLLOWING DISCLAIMER, AND
C**    THE UNDERLYING SOURCE CODE.
C**
C**  - ALL MODIFICATIONS TO THIS SOFTWARE MUST BE CLEARLY DOCUMENTED, 
C**    AND ARE SOLELY THE RESPONSIBILITY OF THE AGENT MAKING THE 
C**    MODIFICATIONS.
C**
C**  - IF SIGNIFICANT MODIFICATIONS OR ENHANCEMENTS ARE MADE TO THIS
C**    SOFTWARE, THE FSL SOFTWARE POLICY MANAGER 
C**    (softwaremgr.fsl@noaa.gov) BE NOTIFIED.
C**
C**  THIS SOFTWARE AND ITS DOCUMENTATION ARE IN THE PUBLIC DOMAIN AND 
C**  ARE FURNISHED "AS IS."  THE AUTHORS, THE UNITED STATES GOVERNMENT,
C**  ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO 
C**  WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE
C**  AND DOCUMENTATION FOR ANY PURPOSE.  THEY ASSUME NO RESPONSIBILITY 
C**  (1) FOR THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO 
C**  PROVIDE TECHNICAL SUPPORT TO USERS.
C**---------------------------------------------------------------------
