C$$$  SUBPROGRAM DOCUMENTATION BLOCK
C                .      .    .                                       .
C SUBPROGRAM:    MQCINQ      INQUIRE ABOUT QC AVAILABILITY PER VARIABLE
C   PRGMMR: M. BARTH         ORG: FSL        DATE: 99-09-28
C
C ABSTRACT: FUNCTION TO RETURN INFO ABOUT WHAT LEVEL OF QC IS AVAILABLE
C   FOR A SINGLE VARIABLE.  THE FUNCTIONAL RETURN CAN BE USED THE
C   IQCTYPE ARGUMENT WHEN CALLING THE MSETQC ROUTINE.
C
C PROGRAM HISTORY LOG:
C   99-09-28  M. BARTH    ORIGINAL VERSION
C   00-03-23  M. BARTH    VQCSTG IS NOW A FUNCTION OF DATA TYPE AS WELL
C                         AS VARIABLE.
C   01-07-26  M. BARTH    CHANGED INV_VCN_P STATUS TO INV_INTV_P
C
C USAGE:    MQCINQ = MQCINQ(VCN,STATUS)
C
C   INPUT ARGUMENT LIST:
C     VCN      - I       VARIABLE CODE NUMBER
C
C   OUTPUT ARGUMENT LIST:
C     MQCINQ   - I       0 - NO QC AVAILABLE
C                        1 - STAGE 1 QC CHECKS
C                        2 - STAGE 2 QC CHECKS
C                        3 - STAGE 3 QC CHECKS
C     STATUS   - I       0 - SUCCESS, OR ERROR CODE
C
C SUBPROGRAMS CALLED:
C     UNIQUE:    MERROR
C
C REMARKS:
C   THE MADIS SUBSYSTEM APPROPRIATE TO THE VARIABLE (E.G., 'SFC')
C   MUST HAVE BEEN INITIALIZED PRIOR TO CALLING THIS ROUTINE.
C
C ATTRIBUTES:
C   LANGUAGE: FORTRAN-77 + EXTENSIONS
C   MACHINE:  UNIX
C$$$
      INTEGER FUNCTION MQCINQ (VCN,STATUS)

C     ------------------------------------------------------------------
C     INCLUDES AND COMMONS
C     ------------------------------------------------------------------
      INCLUDE 'IMPLICIT'
      INCLUDE 'MADISCON'
      INCLUDE 'MADISCOM'

C     ------------------------------------------------------------------
C     ARGUMENTS
C     ------------------------------------------------------------------
      INTEGER VCN,STATUS

      MQCINQ = 0

      IF(VCN.LT.0.OR.VCN.GT.MAX_VARCOD_P)THEN

         STATUS = INV_INTV_P
         CALL MERROR('MQCINQ: INVALID INTERNAL VARIABLE')

      ELSE IF(CDTYPE.LT.0.OR.CDTYPE.GT.MAX_DTYPE_P-1)THEN

         STATUS = SELSUB_NOTINIT_P
         CALL MERROR('MQCINQ: SELECTED SUBSYSTEM NOT INITIALIZED')

      ELSE IF(DTYPE_INIT(CDTYPE).NE.INIT_P)THEN

         STATUS = SELSUB_NOTINIT_P
         CALL MERROR('MQCINQ: SELECTED SUBSYSTEM NOT INITIALIZED')

      ELSE

         STATUS = SUCCESS_P
         MQCINQ = VQCSTG(VCN,CDTYPE)

      ENDIF

      RETURN
      END
C**---------------------------------------------------------------------
C**REQUIRED STANDARD FSL DISCLAIMER (NOVEMBER 2000)
C**---------------------------------------------------------------------
C**  OPEN SOURCE LICENSE/DISCLAIMER,  FORECAST SYSTEMS LABORATORY
C**  NOAA/OAR/FSL, 325 BROADWAY BOULDER, CO 80305
C**
C**  THIS SOFTWARE IS DISTRIBUTED UNDER THE OPEN SOURCE DEFINITION, 
C**  WHICH MAY BE FOUND AT http://www.opensource.org/osd.html.
C**
C**  IN PARTICULAR, REDISTRIBUTION AND USE IN SOURCE AND BINARY FORMS,
C**  WITH OR WITHOUT MODIFICATION, ARE PERMITTED PROVIDED THAT THE 
C**  FOLLOWING CONDITIONS ARE MET:
C**
C**  - REDISTRIBUTIONS OF SOURCE CODE MUST RETAIN THIS NOTICE, THIS LIST
C**    OF CONDITIONS AND THE FOLLOWING DISCLAIMER.
C**
C**  - REDISTRIBUTIONS IN BINARY FORM MUST PROVIDE ACCESS TO THIS 
C**    NOTICE, THIS LIST OF CONDITIONS AND THE FOLLOWING DISCLAIMER, AND
C**    THE UNDERLYING SOURCE CODE.
C**
C**  - ALL MODIFICATIONS TO THIS SOFTWARE MUST BE CLEARLY DOCUMENTED, 
C**    AND ARE SOLELY THE RESPONSIBILITY OF THE AGENT MAKING THE 
C**    MODIFICATIONS.
C**
C**  - IF SIGNIFICANT MODIFICATIONS OR ENHANCEMENTS ARE MADE TO THIS
C**    SOFTWARE, THE FSL SOFTWARE POLICY MANAGER 
C**    (softwaremgr.fsl@noaa.gov) BE NOTIFIED.
C**
C**  THIS SOFTWARE AND ITS DOCUMENTATION ARE IN THE PUBLIC DOMAIN AND 
C**  ARE FURNISHED "AS IS."  THE AUTHORS, THE UNITED STATES GOVERNMENT,
C**  ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO 
C**  WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE
C**  AND DOCUMENTATION FOR ANY PURPOSE.  THEY ASSUME NO RESPONSIBILITY 
C**  (1) FOR THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO 
C**  PROVIDE TECHNICAL SUPPORT TO USERS.
C**---------------------------------------------------------------------
