C$$$  SUBPROGRAM DOCUMENTATION BLOCK
C                .      .    .                                       .
C SUBPROGRAM:    MSATWNDINIT INITIALIZE MADIS SATWND DATA
C   PRGMMR: M. BARTH         ORG: FSL        DATE: 03-09-24
C
C ABSTRACT: READ FILES TO GET PARAMETERS SPECIFIYING WHAT WE NEED TO
C   KNOW TO READ NETCDF VARIABLES AND PROCESS THEM FOR SATWND DATASETS,
C   AND FOR ANY OTHER INFO NEEDED ONE TIME FOR SATWND PROCESSING.
C
C PROGRAM HISTORY LOG:
C   03-09-24  M. BARTH    ORIGINAL VERSION
C
C USAGE:    CALL MSATWNDINIT (SATWNDTBL,STATUS)
C
C   INPUT ARGUMENT LIST:
C
C     SATWNDTBL- C       FILENAME OF THE MADIS SATWND TABLE
C
C   OUTPUT ARGUMENT LIST:
C     STATUS   - I       SUCCESS_P OR FAILURE CODE
C
C   INPUT FILES:
C     SATWNDTBL- FILE SPECIFYING THE VARIABLES IN THE MADIS NETCDF FILES
C
C SUBPROGRAMS CALLED:
C     UNIQUE:    MSATWNDTBL
C
C REMARKS:
C   - LIMITED ERROR CHECKING IS DONE ON THE TABLE, AS IT'S MEANT TO
C     BE STATIC AND CREATED AT CODE DEVELOPMENT TIME.
C   - THE MADISCOM PROVIDER ARRAYS (NPVD, PVDNAME, ETC.) HAVE SATWND
C     PROVIDERS IN ROW 1, HYDRO PROVIDERS IN ROW 2, MAP PROVIDERS
C     IN ROW 3, RDMTR PROVIDERS IN ROW 4, AND SATWND PROVIDERS IN ROW 5.
C   - THE DEFAULT PROVIDER SELECTION IS 'ALL-GOES-O', FOR BOTH GOES
C     SATELLITES, OPERATIONAL PRODUCTS.
C
C ATTRIBUTES:
C   LANGUAGE: FORTRAN-77 + EXTENSIONS
C   MACHINE:  UNIX
C$$$

      SUBROUTINE MSATWNDINIT(SATWNDTBL,STATUS)

C     INCLUDES AND COMMONS
C     ------------------------------------------------------------------
      INCLUDE 'IMPLICIT'
      INCLUDE 'MADISCON'
      INCLUDE 'MADISCOM'

C     ------------------------------------------------------------------
C     ARGUMENTS
C     ------------------------------------------------------------------
      CHARACTER*(*) SATWNDTBL
      INTEGER       STATUS

C     ------------------------------------------------------------------
C     LOCAL
C     ------------------------------------------------------------------
      INTEGER       I

C     ---------------------------------------------------------------
C     INITIALIZE MADISCOM VARIABLES.  NOTE THAT THE DEFAULT PROVIDER
C     SELECTION IS ALL-GOES-O (BOTH GOES SATELLITES, OPERATIONAL
C     PRODUCTS).  BECAUSE OF THE SIZE OF THE SATELLITE DATASETS WE
C     DON'T ENABLE EVERYTHING BY DEFAULT.
C     ---------------------------------------------------------------
      SATWDSET_ENBL(1) = .TRUE.
      DO I = 2, MAX_SATWDSET_P
         SATWDSET_ENBL(I) = .FALSE.
      ENDDO
      DO 1201 I = 1, MAX_SUBSRC_P
         PROVDR_ENBL(I,5) = .TRUE.
 1201 CONTINUE

      NNEWPVD(5) = 0
      ALL_ENBL(5) = .TRUE.

      SATWDSET_NAME(1) = 'GOES-OPER-WINDS'
      SATWDSET_NAME(2) = 'GOES-EXPER-WINDS'

      LAST_SATW_ATIME = '         '

      TOTAL_STNS = 0
      DMTYPE = -1
      QCTYPE = 0

      MINBCK = 0
      MINFWD = 0
      RECWIN = 0

      SATW_INIT = INIT_P

C     ------------------------------------------------------------------
C     READ IN THE MADIS SATWND TABLE (DEFINES VARIABLES AND DATASETS).
C     MSATWNDTBL WILL REPORT ANY ERRORS AND SET STATUS.
C     ------------------------------------------------------------------
      CALL MSATWNDTBL(SATWNDTBL,STATUS)
      IF(STATUS.NE.SUCCESS_P)RETURN

      RETURN
      END
C**---------------------------------------------------------------------
C**REQUIRED STANDARD FSL DISCLAIMER (NOVEMBER 2000)
C**---------------------------------------------------------------------
C**  OPEN SOURCE LICENSE/DISCLAIMER,  FORECAST SYSTEMS LABORATORY
C**  NOAA/OAR/FSL, 325 BROADWAY BOULDER, CO 80305
C**
C**  THIS SOFTWARE IS DISTRIBUTED UNDER THE OPEN SOURCE DEFINITION, 
C**  WHICH MAY BE FOUND AT http://www.opensource.org/osd.html.
C**
C**  IN PARTICULAR, REDISTRIBUTION AND USE IN SOURCE AND BINARY FORMS,
C**  WITH OR WITHOUT MODIFICATION, ARE PERMITTED PROVIDED THAT THE 
C**  FOLLOWING CONDITIONS ARE MET:
C**
C**  - REDISTRIBUTIONS OF SOURCE CODE MUST RETAIN THIS NOTICE, THIS LIST
C**    OF CONDITIONS AND THE FOLLOWING DISCLAIMER.
C**
C**  - REDISTRIBUTIONS IN BINARY FORM MUST PROVIDE ACCESS TO THIS 
C**    NOTICE, THIS LIST OF CONDITIONS AND THE FOLLOWING DISCLAIMER, AND
C**    THE UNDERLYING SOURCE CODE.
C**
C**  - ALL MODIFICATIONS TO THIS SOFTWARE MUST BE CLEARLY DOCUMENTED, 
C**    AND ARE SOLELY THE RESPONSIBILITY OF THE AGENT MAKING THE 
C**    MODIFICATIONS.
C**
C**  - IF SIGNIFICANT MODIFICATIONS OR ENHANCEMENTS ARE MADE TO THIS
C**    SOFTWARE, THE FSL SOFTWARE POLICY MANAGER 
C**    (softwaremgr.fsl@noaa.gov) BE NOTIFIED.
C**
C**  THIS SOFTWARE AND ITS DOCUMENTATION ARE IN THE PUBLIC DOMAIN AND 
C**  ARE FURNISHED "AS IS."  THE AUTHORS, THE UNITED STATES GOVERNMENT,
C**  ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO 
C**  WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE
C**  AND DOCUMENTATION FOR ANY PURPOSE.  THEY ASSUME NO RESPONSIBILITY 
C**  (1) FOR THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO 
C**  PROVIDE TECHNICAL SUPPORT TO USERS.
C**---------------------------------------------------------------------
