C$$$  SUBPROGRAM DOCUMENTATION BLOCK
C                .      .    .                                       .
C SUBPROGRAM:    MSETCOR     SET OBSERVATION CORRECTION OPTIONS
C   PRGMMR: M. BARTH         ORG: FSL        DATE: 00-04-03
C
C ABSTRACT: SET OBSERVATION CORRECTION OPTIONS
C
C PROGRAM HISTORY LOG:
C   00-04-03  M. BARTH    ORIGINAL VERSION
C   01-06-05  M. BARTH    CLEAR THE LAST-TIME-READ FIELD FOR ALL
C                         DATASETS -- NEED TO FORCE RELOADING OF
C                         THE DATA.
C
C USAGE:    CALL MSETCOR (ICTYPE,STATUS)
C
C   INPUT ARGUMENT LIST:
C     ICTYPE  - I        OBSERVATION CORRECTION HANDLING:
C
C                        0 - MAKE RECOMMENDED CORRECTIONS (DEFAULT)
C                        1 - DO NOT MAKE RECOMMENDED CORRECTIONS
C
C   OUTPUT ARGUMENT LIST:
C     STATUS   - I       0 - SUCCESS, OR ERROR CODE
C
C SUBPROGRAMS CALLED:
C     UNIQUE:    MERROR
C
C REMARKS:
C   - WITHOUT CALLING THIS ROUTINE, BY DEFAULT ANY CORRECTIONS
C     RECOMMENDED BY THE AUTOMATED QC WILL BE MADE (ICTYPE = 0).
C   - CORRECTIONS ARE ONLY "RECOMMENDED" WHEN STRONG CONFIDENCE
C     EXISTS IN THE ABILITY TO CORRECT.
C   - CURRENT LIST OF RECOMMENDED CORRECTIONS:
C
C     1) RAOB MANDATORY LEVEL HEIGHTS (HYDROSTATIC CHECK)
C     2) RAOB MANDATORY LEVEL TEMPERATURES (HYDROSTATIC CHECK)
C
C ATTRIBUTES:
C   LANGUAGE: FORTRAN-77 + EXTENSIONS
C   MACHINE:  UNIX
C$$$

      SUBROUTINE MSETCOR (ICTYPE,STATUS)

C     ------------------------------------------------------------------
C     INCLUDES AND COMMONS
C     ------------------------------------------------------------------
      INCLUDE 'IMPLICIT'
      INCLUDE 'MADISCON'
      INCLUDE 'MADISCOM'

C     ------------------------------------------------------------------
C     ARGUMENTS
C     ------------------------------------------------------------------
      INTEGER ICTYPE,STATUS

C     ------------------------------------------------------------------
C     LOCAL
C     ------------------------------------------------------------------
      INTEGER I

C     ------------------------------------------------------------------
C     IF NO SUBSYSTEM HAS BEEN INITIALIZED, RETURN WITH ERROR.
C     ------------------------------------------------------------------
      IF(MADIS_INIT.NE.INIT_P)THEN
         STATUS = SUB_NOTINIT_P
         CALL MERROR('MSETCOR: NO MADIS SUBSYSTEM INITIALIZED')
         RETURN
      ENDIF

C     ------------------------------------------------------------------
C     KNOCK OUT THE CURRENT CORRECTION SELECTION.  ALSO CLEAR THE
C     LAST-TIME-READ FIELD FOR ALL DATASET TYPES SO THAT DATA WILL
C     HAVE TO BE RELOADED.  VALIDATE INPUT, AND FILL THE SELECTION IN
C     THE COMMON IF INPUT'S VALID.
C     ------------------------------------------------------------------
      CORTYP = 0
      DO 1 I = 0, MAX_DTYPE_P - 1
         LAST_DTYPE_ATIME(I) = '         '
 1    CONTINUE

      IF(ICTYPE.LT.0.OR.ICTYPE.GT.1)THEN

         CALL MERROR('MSETCOR: INVALID CORRECTION TYPE')

      ELSE

         CORTYP = ICTYPE
         STATUS = SUCCESS_P

      ENDIF

      RETURN
      END
C**---------------------------------------------------------------------
C**REQUIRED STANDARD FSL DISCLAIMER (NOVEMBER 2000)
C**---------------------------------------------------------------------
C**  OPEN SOURCE LICENSE/DISCLAIMER,  FORECAST SYSTEMS LABORATORY
C**  NOAA/OAR/FSL, 325 BROADWAY BOULDER, CO 80305
C**
C**  THIS SOFTWARE IS DISTRIBUTED UNDER THE OPEN SOURCE DEFINITION, 
C**  WHICH MAY BE FOUND AT http://www.opensource.org/osd.html.
C**
C**  IN PARTICULAR, REDISTRIBUTION AND USE IN SOURCE AND BINARY FORMS,
C**  WITH OR WITHOUT MODIFICATION, ARE PERMITTED PROVIDED THAT THE 
C**  FOLLOWING CONDITIONS ARE MET:
C**
C**  - REDISTRIBUTIONS OF SOURCE CODE MUST RETAIN THIS NOTICE, THIS LIST
C**    OF CONDITIONS AND THE FOLLOWING DISCLAIMER.
C**
C**  - REDISTRIBUTIONS IN BINARY FORM MUST PROVIDE ACCESS TO THIS 
C**    NOTICE, THIS LIST OF CONDITIONS AND THE FOLLOWING DISCLAIMER, AND
C**    THE UNDERLYING SOURCE CODE.
C**
C**  - ALL MODIFICATIONS TO THIS SOFTWARE MUST BE CLEARLY DOCUMENTED, 
C**    AND ARE SOLELY THE RESPONSIBILITY OF THE AGENT MAKING THE 
C**    MODIFICATIONS.
C**
C**  - IF SIGNIFICANT MODIFICATIONS OR ENHANCEMENTS ARE MADE TO THIS
C**    SOFTWARE, THE FSL SOFTWARE POLICY MANAGER 
C**    (softwaremgr.fsl@noaa.gov) BE NOTIFIED.
C**
C**  THIS SOFTWARE AND ITS DOCUMENTATION ARE IN THE PUBLIC DOMAIN AND 
C**  ARE FURNISHED "AS IS."  THE AUTHORS, THE UNITED STATES GOVERNMENT,
C**  ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO 
C**  WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE
C**  AND DOCUMENTATION FOR ANY PURPOSE.  THEY ASSUME NO RESPONSIBILITY 
C**  (1) FOR THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO 
C**  PROVIDE TECHNICAL SUPPORT TO USERS.
C**---------------------------------------------------------------------
